.. _glossary:

Glossary
========

.. glossary::
   :sorted:

   grid
     This refers to a "table of data, with features" essentially.
     Sometimes it may be displayed as a simple table with no features,
     or sometimes it has sortable columns, search filters and other
     tools.

     See also the :class:`~wuttaweb.grids.base.Grid` base class.
